<?php

namespace WilokeVisualCard\Widgets;

use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Widget_Base;
use WilokeVisualCard\Shared\HtmlHelper;

class VisualCardWidget extends Widget_Base
{

	public function get_style_depends()
	{
		return [WILOKE_VISUAL_CARD_ID];
	}

	public function get_script_depends()
	{
		return [WILOKE_VISUAL_CARD_ID];
	}

	public function get_name()
	{
		return WILOKE_VISUAL_CARD_ID . '-settings';
	}

	public function get_title()
	{
		return "Wiloke Visual Card";
	}

	public function get_icon()
	{
		return 'eicon-person';
	}

	public function get_categories()
	{
		return ['wiloke-category'];
	}

	protected function _register_controls()
	{
		$this->start_controls_section(
			'wiloke_swaying_settings_section_content',
			[
				'label' => esc_html__('Settings', 'wiloke-3d-slider'),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);


		// Repeater control for Title and Description fields
		$repeater = new Repeater();
		$repeater->add_control(
			"name",
			[
				"label"   => esc_html__("Name", "wiloke-visual-card"),
				"type"    => Controls_Manager::TEXT,
				"default" => "Name"
			]
		);

		$repeater->add_control(
			"description",
			[
				"label"   => esc_html__("Description", "wiloke-visual-card"),
				"type"    => Controls_Manager::WYSIWYG,
				"default" => "We specialize in creating responsive designs that look great on desktop, tablet, and mobile devices, ensuring your site is accessible to all your visitors."
			]
		);

		$repeater->add_control(
			"image",
			[
				"label"       => esc_html__("Image", "wiloke-visual-card"),
				"description" => esc_html__("Recommended size: 1000x1500px", "wiloke-visual-card"),
				"type"        => Controls_Manager::MEDIA
			]
		);

		$repeater->add_control(
			"btn_name",
			[
				"label"   => esc_html__("Button name", "wiloke-visual-card"),
				"type"    => Controls_Manager::TEXT,
				"default" => "Join now"
			]
		);

		$repeater->add_control(
			"btn_link",
			[
				"label" => esc_html__("Button link", "wiloke-visual-card"),
				"type"  => Controls_Manager::URL
			]
		);

		// Repeatable control for Title and Description fields
		$this->add_control(
			'items',
			[
				'label'  => esc_html__('Items', 'wiloke-swaying-photo-gallery'),
				'type'   => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls()
			]
		);

		$this->end_controls_section();
	}

	protected function render()
	{
		$aSettings = $this->get_settings_for_display();

		if (empty($aSettings)) {
			return;
		}

		if (empty($aSettings["items"])) {
			return;
		}

		?>
		<div class="<?php echo esc_attr(HtmlHelper::autoPrefix("wrapper")); ?>">
			<?php
			foreach ($aSettings["items"] as $aItem) {
				HtmlHelper::renderItem($aItem, $aSettings);
			}
			?>
		</div>
		<?php
	}
}
